@@ -472,5 +472,8 @@ class CloudSchedulerGrpcAsyncIOTransport(CloudSchedulerTransport):
             )
         return self._stubs["run_job"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("CloudSchedulerGrpcAsyncIOTransport",)
