@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,14 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.scheduler_v1beta1.types import target
-from google.protobuf import duration_pb2 as duration  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-from google.rpc import status_pb2 as gr_status  # type: ignore
+from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+from google.rpc import status_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -155,43 +152,34 @@ class Job(proto.Message):
         DISABLED = 3
         UPDATE_FAILED = 4
 
-    name = proto.Field(proto.STRING, number=1)
-
-    description = proto.Field(proto.STRING, number=2)
-
+    name = proto.Field(proto.STRING, number=1,)
+    description = proto.Field(proto.STRING, number=2,)
     pubsub_target = proto.Field(
         proto.MESSAGE, number=4, oneof="target", message=target.PubsubTarget,
     )
-
     app_engine_http_target = proto.Field(
         proto.MESSAGE, number=5, oneof="target", message=target.AppEngineHttpTarget,
     )
-
     http_target = proto.Field(
         proto.MESSAGE, number=6, oneof="target", message=target.HttpTarget,
     )
-
-    schedule = proto.Field(proto.STRING, number=20)
-
-    time_zone = proto.Field(proto.STRING, number=21)
-
+    schedule = proto.Field(proto.STRING, number=20,)
+    time_zone = proto.Field(proto.STRING, number=21,)
     user_update_time = proto.Field(
-        proto.MESSAGE, number=9, message=timestamp.Timestamp,
+        proto.MESSAGE, number=9, message=timestamp_pb2.Timestamp,
     )
-
     state = proto.Field(proto.ENUM, number=10, enum=State,)
-
-    status = proto.Field(proto.MESSAGE, number=11, message=gr_status.Status,)
-
-    schedule_time = proto.Field(proto.MESSAGE, number=17, message=timestamp.Timestamp,)
-
+    status = proto.Field(proto.MESSAGE, number=11, message=status_pb2.Status,)
+    schedule_time = proto.Field(
+        proto.MESSAGE, number=17, message=timestamp_pb2.Timestamp,
+    )
     last_attempt_time = proto.Field(
-        proto.MESSAGE, number=18, message=timestamp.Timestamp,
+        proto.MESSAGE, number=18, message=timestamp_pb2.Timestamp,
     )
-
     retry_config = proto.Field(proto.MESSAGE, number=19, message="RetryConfig",)
-
-    attempt_deadline = proto.Field(proto.MESSAGE, number=22, message=duration.Duration,)
+    attempt_deadline = proto.Field(
+        proto.MESSAGE, number=22, message=duration_pb2.Duration,
+    )
 
 
 class RetryConfig(proto.Message):
@@ -268,21 +256,17 @@ class RetryConfig(proto.Message):
             The default value of this field is 5.
     """
 
-    retry_count = proto.Field(proto.INT32, number=1)
-
+    retry_count = proto.Field(proto.INT32, number=1,)
     max_retry_duration = proto.Field(
-        proto.MESSAGE, number=2, message=duration.Duration,
+        proto.MESSAGE, number=2, message=duration_pb2.Duration,
     )
-
     min_backoff_duration = proto.Field(
-        proto.MESSAGE, number=3, message=duration.Duration,
+        proto.MESSAGE, number=3, message=duration_pb2.Duration,
     )
-
     max_backoff_duration = proto.Field(
-        proto.MESSAGE, number=4, message=duration.Duration,
+        proto.MESSAGE, number=4, message=duration_pb2.Duration,
     )
-
-    max_doublings = proto.Field(proto.INT32, number=5)
+    max_doublings = proto.Field(proto.INT32, number=5,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
