@@ -20,5 +20,7 @@ from google.cloud import scheduler_v1
 class TestSystemScheduler(object):
     def test_create_job(self):
         client = scheduler_v1.CloudSchedulerClient()
-        parent = client.location_path(os.environ.get("PROJECT_ID"), "us-central1")
-        client.list_jobs(parent)
+        project_id = os.environ.get("PROJECT_ID")
+        location_id = "us-central1"
+        parent = f"projects/{project_id}/locations/{location_id}"
+        client.list_jobs(parent=parent)
